pub struct ArenaPlaceRestriction {
pub min_place: Option<i64>,
pub max_place: Option<i64>,
}Fields
min_place: Option<i64>max_place: Option<i64>Trait Implementations
Sourceimpl Clone for ArenaPlaceRestriction
impl Clone for ArenaPlaceRestriction
Sourcefn clone(&self) -> ArenaPlaceRestriction
fn clone(&self) -> ArenaPlaceRestriction
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaPlaceRestriction
impl Debug for ArenaPlaceRestriction
Sourceimpl<'de> Deserialize<'de> for ArenaPlaceRestriction
impl<'de> Deserialize<'de> for ArenaPlaceRestriction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaPlaceRestriction
impl JsonSchema for ArenaPlaceRestriction
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArenaPlaceRestriction
impl PartialEq for ArenaPlaceRestriction
Sourceimpl Serialize for ArenaPlaceRestriction
impl Serialize for ArenaPlaceRestriction
Sourceimpl Tsify for ArenaPlaceRestriction
impl Tsify for ArenaPlaceRestriction
const DECL: &'static str = "export interface ArenaPlaceRestriction {\n min_place: number | null;\n max_place: number | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ArenaPlaceRestriction
impl StructuralPartialEq for ArenaPlaceRestriction