pub struct ArenaRatingRestriction {
pub min_rating: Option<i64>,
pub max_rating: Option<i64>,
}Fields
min_rating: Option<i64>max_rating: Option<i64>Trait Implementations
Sourceimpl Clone for ArenaRatingRestriction
impl Clone for ArenaRatingRestriction
Sourcefn clone(&self) -> ArenaRatingRestriction
fn clone(&self) -> ArenaRatingRestriction
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ArenaRatingRestriction
impl Debug for ArenaRatingRestriction
Sourceimpl<'de> Deserialize<'de> for ArenaRatingRestriction
impl<'de> Deserialize<'de> for ArenaRatingRestriction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ArenaRatingRestriction
impl JsonSchema for ArenaRatingRestriction
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ArenaRatingRestriction
impl PartialEq for ArenaRatingRestriction
Sourceimpl Serialize for ArenaRatingRestriction
impl Serialize for ArenaRatingRestriction
Sourceimpl Tsify for ArenaRatingRestriction
impl Tsify for ArenaRatingRestriction
const DECL: &'static str = "export interface ArenaRatingRestriction {\n min_rating: number | null;\n max_rating: number | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for ArenaRatingRestriction
impl StructuralPartialEq for ArenaRatingRestriction