pub struct Mail {
pub id: MailId,
pub template_id: MailTemplateId,
pub bundle: Option<BundleStepGeneric>,
pub title: I18nString,
pub message: I18nString,
pub created_at: DateTime<Utc>,
pub expires_at: DateTime<Utc>,
pub is_read: bool,
pub is_claimed: Option<bool>,
pub is_deleted: bool,
}Fields
id: MailIdtemplate_id: MailTemplateIdbundle: Option<BundleStepGeneric>title: I18nStringmessage: I18nStringcreated_at: DateTime<Utc>expires_at: DateTime<Utc>is_read: boolis_claimed: Option<bool>is_deleted: boolTrait Implementations
Sourceimpl CustomType for Mail
impl CustomType for Mail
Sourcefn build(builder: TypeBuilder<'_, Self>)
fn build(builder: TypeBuilder<'_, Self>)
Builds the custom type for use with the [
Engine]. Read moreSourceimpl<'de> Deserialize<'de> for Mail
impl<'de> Deserialize<'de> for Mail
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Mail
impl JsonSchema for Mail
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Tsify for Mail
impl Tsify for Mail
const DECL: &'static str = "export interface Mail {\n id: MailId;\n template_id: MailTemplateId;\n bundle: BundleStepGeneric | null;\n title: I18nString;\n message: I18nString;\n created_at: DateTime<Utc>;\n expires_at: DateTime<Utc>;\n is_read: boolean;\n is_claimed: boolean | null;\n is_deleted: boolean;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for Mail
impl StructuralPartialEq for Mail