pub struct MailRestrictions {
pub arena_rating: Option<ArenaRatingRestriction>,
pub power: Option<PowerRestriction>,
pub arena_place: Option<ArenaPlaceRestriction>,
pub pve_progress: Option<PVEProgressRestriction>,
}Fields
arena_rating: Option<ArenaRatingRestriction>power: Option<PowerRestriction>arena_place: Option<ArenaPlaceRestriction>pve_progress: Option<PVEProgressRestriction>Trait Implementations
Sourceimpl Clone for MailRestrictions
impl Clone for MailRestrictions
Sourcefn clone(&self) -> MailRestrictions
fn clone(&self) -> MailRestrictions
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MailRestrictions
impl Debug for MailRestrictions
Sourceimpl<'de> Deserialize<'de> for MailRestrictions
impl<'de> Deserialize<'de> for MailRestrictions
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MailRestrictions
impl JsonSchema for MailRestrictions
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MailRestrictions
impl PartialEq for MailRestrictions
Sourceimpl Serialize for MailRestrictions
impl Serialize for MailRestrictions
Sourceimpl Tsify for MailRestrictions
impl Tsify for MailRestrictions
const DECL: &'static str = "export interface MailRestrictions {\n arena_rating: ArenaRatingRestriction | null;\n power: PowerRestriction | null;\n arena_place: ArenaPlaceRestriction | null;\n pve_progress: PVEProgressRestriction | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for MailRestrictions
impl StructuralPartialEq for MailRestrictions