pub struct MailSendType {
pub scheduled_at: Option<String>,
pub repeat: Option<MailRepeatType>,
}Fields
scheduled_at: Option<String>repeat: Option<MailRepeatType>Trait Implementations
Sourceimpl Clone for MailSendType
impl Clone for MailSendType
Sourcefn clone(&self) -> MailSendType
fn clone(&self) -> MailSendType
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MailSendType
impl Debug for MailSendType
Sourceimpl<'de> Deserialize<'de> for MailSendType
impl<'de> Deserialize<'de> for MailSendType
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MailSendType
impl JsonSchema for MailSendType
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MailSendType
impl PartialEq for MailSendType
Sourceimpl Serialize for MailSendType
impl Serialize for MailSendType
Sourceimpl Tsify for MailSendType
impl Tsify for MailSendType
const DECL: &'static str = "export interface MailSendType {\n scheduled_at: string | null;\n repeat: MailRepeatType | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for MailSendType
impl StructuralPartialEq for MailSendType