pub struct MailTemplate {
pub id: MailTemplateId,
pub title: I18nString,
pub message: I18nString,
pub bundle_id: Option<BundleId>,
pub lifetime_secs: i64,
pub send_type: MailSendType,
pub is_auto_send: bool,
pub restrictions: Option<MailRestrictions>,
}Fields
id: MailTemplateIdtitle: I18nStringmessage: I18nStringbundle_id: Option<BundleId>lifetime_secs: i64send_type: MailSendTypeis_auto_send: boolrestrictions: Option<MailRestrictions>Trait Implementations
Sourceimpl Clone for MailTemplate
impl Clone for MailTemplate
Sourcefn clone(&self) -> MailTemplate
fn clone(&self) -> MailTemplate
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MailTemplate
impl Debug for MailTemplate
Sourceimpl<'de> Deserialize<'de> for MailTemplate
impl<'de> Deserialize<'de> for MailTemplate
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MailTemplate
impl JsonSchema for MailTemplate
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MailTemplate
impl PartialEq for MailTemplate
Sourceimpl Serialize for MailTemplate
impl Serialize for MailTemplate
Sourceimpl Tsify for MailTemplate
impl Tsify for MailTemplate
const DECL: &'static str = "export interface MailTemplate {\n id: MailTemplateId;\n title: I18nString;\n message: I18nString;\n bundle_id: BundleId | null;\n lifetime_secs: number;\n send_type: MailSendType;\n is_auto_send: boolean;\n restrictions: MailRestrictions | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for MailTemplate
impl StructuralPartialEq for MailTemplate