pub struct PowerRestriction {
pub min_power: Option<i64>,
pub max_power: Option<i64>,
}Fields
min_power: Option<i64>max_power: Option<i64>Trait Implementations
Sourceimpl Clone for PowerRestriction
impl Clone for PowerRestriction
Sourcefn clone(&self) -> PowerRestriction
fn clone(&self) -> PowerRestriction
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PowerRestriction
impl Debug for PowerRestriction
Sourceimpl<'de> Deserialize<'de> for PowerRestriction
impl<'de> Deserialize<'de> for PowerRestriction
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PowerRestriction
impl JsonSchema for PowerRestriction
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
fn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PowerRestriction
impl PartialEq for PowerRestriction
Sourceimpl Serialize for PowerRestriction
impl Serialize for PowerRestriction
Sourceimpl Tsify for PowerRestriction
impl Tsify for PowerRestriction
const DECL: &'static str = "export interface PowerRestriction {\n min_power: number | null;\n max_power: number | null;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
impl Eq for PowerRestriction
impl StructuralPartialEq for PowerRestriction